==> perl-DateTime-Locale-1.22-1-src.tar.xz: DateTime-Locale-1.22/share/de.pl <==
{
  am_pm_abbreviated => [
    "vorm.",
    "nachm.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH 'Uhr'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-one" => "'Woche' W 'im' MMM",
    "MMMMW-count-other" => "'Woche' W 'im' MMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMd => "d.MM.",
    MMdd => "dd.MM.",
    Md => "d.M.",
    d => "d",
    h => "h 'Uhr' a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMMdd => "dd.MM.y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'Woche' w 'des' 'Jahres' Y",
    "yw-count-other" => "'Woche' w 'des' 'Jahres' Y",
  },
  code => "de",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "dd.MM.y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} 'um' {0}",
  datetime_format_long => "{1} 'um' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Mo.",
    "Di.",
    "Mi.",
    "Do.",
    "Fr.",
    "Sa.",
    "So.",
  ],
  day_format_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Montag",
    "Dienstag",
    "Mittwoch",
    "Donnerstag",
    "Freitag",
    "Samstag",
    "Sonntag",
  ],
  day_stand_alone_abbreviated => [
    "Mo",
    "Di",
    "Mi",
    "Do",
    "Fr",
    "Sa",
    "So",
  ],
  day_stand_alone_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Montag",
    "Dienstag",
    "Mittwoch",
    "Donnerstag",
    "Freitag",
    "Samstag",
    "Sonntag",
  ],
  era_abbreviated => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_narrow => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_wide => [
    "v. Chr.",
    "n. Chr.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "German",
  month_format_abbreviated => [
    "Jan.",
    "Feb.",
    "M\N{U+00e4}rz",
    "Apr.",
    "Mai",
    "Juni",
    "Juli",
    "Aug.",
    "Sep.",
    "Okt.",
    "Nov.",
    "Dez.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}r",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember",
  ],
  name => "German",
  native_language => "Deutsch",
  native_name => "Deutsch",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}

==> perl-DateTime-Locale-1.24-1-src.tar.xz: DateTime-Locale-1.24/share/de.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH 'Uhr'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-one" => "'Woche' W 'im' MMMM",
    "MMMMW-count-other" => "'Woche' W 'im' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMd => "d.MM.",
    MMdd => "dd.MM.",
    Md => "d.M.",
    d => "d",
    h => "h 'Uhr' a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMMdd => "dd.MM.y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'Woche' w 'des' 'Jahres' Y",
    "yw-count-other" => "'Woche' w 'des' 'Jahres' Y",
  },
  code => "de",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "dd.MM.y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} 'um' {0}",
  datetime_format_long => "{1} 'um' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Mo.",
    "Di.",
    "Mi.",
    "Do.",
    "Fr.",
    "Sa.",
    "So.",
  ],
  day_format_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Montag",
    "Dienstag",
    "Mittwoch",
    "Donnerstag",
    "Freitag",
    "Samstag",
    "Sonntag",
  ],
  day_stand_alone_abbreviated => [
    "Mo",
    "Di",
    "Mi",
    "Do",
    "Fr",
    "Sa",
    "So",
  ],
  day_stand_alone_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Montag",
    "Dienstag",
    "Mittwoch",
    "Donnerstag",
    "Freitag",
    "Samstag",
    "Sonntag",
  ],
  era_abbreviated => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_narrow => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_wide => [
    "v. Chr.",
    "n. Chr.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "German",
  month_format_abbreviated => [
    "Jan.",
    "Feb.",
    "M\N{U+00e4}rz",
    "Apr.",
    "Mai",
    "Juni",
    "Juli",
    "Aug.",
    "Sept.",
    "Okt.",
    "Nov.",
    "Dez.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}r",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}rz",
    "April",
    "Mai",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember",
  ],
  name => "German",
  native_language => "Deutsch",
  native_name => "Deutsch",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
